searchData={"items":[{"type":"module","title":"SimpleForm.Attrs","doc":"`SimpleForm.Attrs` implements functions for manipulating XML attributes,\nsuch as getting a specific attribute from an XML element or list of XML attributes.","ref":"SimpleForm.Attrs.html"},{"type":"function","title":"SimpleForm.Attrs.get/3","doc":"Get an attribute from an XML element or its list of attributes.","ref":"SimpleForm.Attrs.html#get/3"},{"type":"function","title":"Examples - SimpleForm.Attrs.get/3","doc":"iex> SimpleForm.Attrs.get({\"w:p\", [{\"a\", 123}, {\"b\", 6}], []}, \"a\")\n    {\"a\", 123}\n    iex> SimpleForm.Attrs.get([{\"a\", 123}, {\"b\", 6}], \"b\")\n    {\"b\", 6}\n    iex> SimpleForm.Attrs.get([{\"a\", 123}, {\"b\", 6}], \"c\")\n    nil\n    iex> SimpleForm.Attrs.get([{\"a\", 123}, {\"b\", 6}], \"c\", \"default\")\n    \"default\"\n    iex> SimpleForm.Attrs.get(nil, \"a\")\n    nil\n    iex> SimpleForm.Attrs.get(nil, \"a\", \"default\")\n    \"default\"","ref":"SimpleForm.Attrs.html#get/3-examples"},{"type":"function","title":"SimpleForm.Attrs.get_many/2","doc":"Get multiple attributes from an XML element or its list of attributes.\nThe order and placement of the attributes in the list is preserved w.r.t. the given keys.\n\nThis function is more performant than calling `get/3` multiple times,\nas it only iterates over `elements` once.","ref":"SimpleForm.Attrs.html#get_many/2"},{"type":"function","title":"Examples - SimpleForm.Attrs.get_many/2","doc":"iex> SimpleForm.Attrs.get_many({\"w:p\", [{\"a\", 123}, {\"b\", 6}, {\"c\", 42}], []}, [\"a\", \"b\", \"c\"])\n    [{\"a\", 123}, {\"b\", 6}, {\"c\", 42}]\n    iex> SimpleForm.Attrs.get_many([{\"a\", 123}, {\"b\", 6}, {\"c\", 42}], [\"a\", \"c\"])\n    [{\"a\", 123}, {\"c\", 42}]\n    iex> SimpleForm.Attrs.get_many([{\"a\", 123}, {\"b\", 6}, {\"c\", 42}], [\"a\", \"d\", \"c\"])\n    [{\"a\", 123}, nil, {\"c\", 42}]\n    iex> SimpleForm.Attrs.get_many([{\"a\", 123}, {\"b\", 6}, {\"c\", 42}], [\"d\", \"e\"])\n    [nil, nil]","ref":"SimpleForm.Attrs.html#get_many/2-examples"},{"type":"function","title":"SimpleForm.Attrs.get_many_value/2","doc":"Get multiple attribute values from an XML element or its list of attributes.\nThe order and placement of the attribute value in the list is preserved w.r.t. the given keys.\n\nThis function is more performant than calling `get_value/3` multiple times,\nas it only iterates over `elements` once.","ref":"SimpleForm.Attrs.html#get_many_value/2"},{"type":"function","title":"Examples - SimpleForm.Attrs.get_many_value/2","doc":"iex> SimpleForm.Attrs.get_many_value({\"w:p\", [{\"a\", 123}, {\"b\", 6}, {\"c\", 42}], []}, [\"a\", \"b\", \"c\"])\n    [123, 6, 42]\n    iex> SimpleForm.Attrs.get_many_value([{\"a\", 123}, {\"b\", 6}, {\"c\", 42}], [\"a\", \"c\"])\n    [123, 42]\n    iex> SimpleForm.Attrs.get_many_value([{\"a\", 123}, {\"b\", 6}, {\"c\", 42}], [\"a\", \"d\", \"c\"])\n    [123, nil, 42]\n    iex> SimpleForm.Attrs.get_many_value([{\"a\", 123}, {\"b\", 6}, {\"c\", 42}], [\"d\", \"e\"])\n    [nil, nil]","ref":"SimpleForm.Attrs.html#get_many_value/2-examples"},{"type":"function","title":"SimpleForm.Attrs.get_value/3","doc":"Get the value of an attribute from an XML element or its list of attributes.","ref":"SimpleForm.Attrs.html#get_value/3"},{"type":"function","title":"Examples - SimpleForm.Attrs.get_value/3","doc":"iex> SimpleForm.Attrs.get_value({\"w:p\", [{\"a\", 123}, {\"b\", 6}], []}, \"a\")\n    123\n    iex> SimpleForm.Attrs.get_value([{\"a\", 123}, {\"b\", 6}], \"b\")\n    6\n    iex> SimpleForm.Attrs.get_value([{\"a\", 123}, {\"b\", 6}], \"c\")\n    nil\n    iex> SimpleForm.Attrs.get_value([{\"a\", 123}, {\"b\", 6}], \"c\", \"default\")\n    \"default\"\n    iex> SimpleForm.Attrs.get_value(nil, \"a\")\n    nil\n    iex> SimpleForm.Attrs.get_value(nil, \"a\", \"default\")\n    \"default\"","ref":"SimpleForm.Attrs.html#get_value/3-examples"},{"type":"function","title":"SimpleForm.Attrs.key/1","doc":"Get the key of an attribute.","ref":"SimpleForm.Attrs.html#key/1"},{"type":"function","title":"Examples - SimpleForm.Attrs.key/1","doc":"iex> SimpleForm.Attrs.key({\"a\", 123})\n    \"a\"\n    iex> SimpleForm.Attrs.key(nil)\n    nil","ref":"SimpleForm.Attrs.html#key/1-examples"},{"type":"function","title":"SimpleForm.Attrs.value/1","doc":"Get the value of an attribute.","ref":"SimpleForm.Attrs.html#value/1"},{"type":"function","title":"Examples - SimpleForm.Attrs.value/1","doc":"iex> SimpleForm.Attrs.value({\"a\", 123})\n    123\n    iex> SimpleForm.Attrs.value(nil)\n    nil","ref":"SimpleForm.Attrs.html#value/1-examples"},{"type":"module","title":"SimpleForm.Element","doc":"SimpleForm.Element implements functions for manipulating XML elements,\nsuch as finding one by name in a list of elements or in the children of another element.","ref":"SimpleForm.Element.html"},{"type":"function","title":"SimpleForm.Element.attrs/1","doc":"Get the attributes of an element.","ref":"SimpleForm.Element.html#attrs/1"},{"type":"function","title":"Examples - SimpleForm.Element.attrs/1","doc":"iex> SimpleForm.Element.attrs(nil)\n    nil\n    iex> SimpleForm.Element.attrs({\"w:p\", [], [\"some text\"]})\n    []\n    iex> SimpleForm.Element.attrs({\"w:p\", [{\"id\", \"1\"}], [\"some text\"]})\n    [{\"id\", \"1\"}]","ref":"SimpleForm.Element.html#attrs/1-examples"},{"type":"function","title":"SimpleForm.Element.children/1","doc":"Get the children of an element.","ref":"SimpleForm.Element.html#children/1"},{"type":"function","title":"Examples - SimpleForm.Element.children/1","doc":"iex> SimpleForm.Element.children(nil)\n    nil\n    iex> SimpleForm.Element.children({\"w:p\", [], []})\n    []\n    iex> SimpleForm.Element.children({\"w:p\", [], [\"some text\"]})\n    [\"some text\"]\n    iex> SimpleForm.Element.children({\"w:p\", [{\"id\", \"1\"}], [\"some text\", \"more text\"]})\n    [\"some text\", \"more text\"]","ref":"SimpleForm.Element.html#children/1-examples"},{"type":"function","title":"SimpleForm.Element.find_by_name/4","doc":"Find an element by name in a list of elements.","ref":"SimpleForm.Element.html#find_by_name/4"},{"type":"function","title":"Options - SimpleForm.Element.find_by_name/4","doc":"* `recursive` (boolean): If true, the function will perform a recursive, depth-first search through the children of each element in the list.","ref":"SimpleForm.Element.html#find_by_name/4-options"},{"type":"function","title":"Examples - SimpleForm.Element.find_by_name/4","doc":"By default, `SimpleForm.Element.find_by_name/4` only searches the list's elements.\n\n    iex> SimpleForm.Element.find_by_name([{\"w:p\", [], []}, {\"w:tbl\", [], []}], \"w:tbl\")\n    {\"w:tbl\", [], []}\n    iex> SimpleForm.Element.find_by_name([{\"w:p\", [], []}, {\"w:tbl\", [], []}], \"w:sdt\")\n    nil\n    iex> SimpleForm.Element.find_by_name([{\"w:p\", [], []}, {\"w:tbl\", [], []}], \"w:sdt\", {\"w:sdt\", [], []})\n    {\"w:sdt\", [], []}\n\nFor a recursive, depth-first search through the children of each element in the list, set the `recursive` option to `true`.\n\n    iex> SimpleForm.Element.find_by_name([{\"w:p\", [], [{\"w:r\", [], [\"some text\"]}]}], \"w:r\", nil, recursive: true)\n    {\"w:r\", [], [\"some text\"]}\n    iex> SimpleForm.Element.find_by_name([{\"w:p\", [], [{\"w:r\", [], [\"some text\"]}]}], \"w:sdt\", nil, recursive: true)\n    nil\n    iex> SimpleForm.Element.find_by_name([{\"w:p\", [], [{\"w:r\", [], [\"some text\"]}, \"  \", {\"w:sdt\", [], []}]}], \"w:sdt\", nil, recursive: true)\n    {\"w:sdt\", [], []}\n    iex> SimpleForm.Element.find_by_name([{\"w:p\", [], [{\"w:r\", [], [\"first text\"]}]}, \"  \", {\"w:p\", [], [{\"w:r\", [], [\"second text\"]}]}], \"w:r\", nil, recursive: true)\n    {\"w:r\", [], [\"first text\"]}\n\nNote: the option `recursive: true` requires setting a default value explicitly, otherwise this option is assumed as the default value.\n\n    iex> SimpleForm.Element.find_by_name([{\"w:p\", [], [{\"w:r\", [], [\"some text\"]}]}], \"w:r\", recursive: true)\n    [recursive: true]\n    iex> SimpleForm.Element.find_by_name([{\"w:p\", [], [{\"w:r\", [], [\"some text\"]}]}], \"w:r\", recursive: false)\n    [recursive: false]","ref":"SimpleForm.Element.html#find_by_name/4-examples"},{"type":"function","title":"SimpleForm.Element.find_many_by_name/2","doc":"Find multiple elements by their names in a list of elements.\nThe order and placement of the elements in the list is preserved w.r.t. the given names.\n\nThis function is more performant than calling `find_by_name/3` multiple times,\nas it only iterates over `elements` once.","ref":"SimpleForm.Element.html#find_many_by_name/2"},{"type":"function","title":"Examples - SimpleForm.Element.find_many_by_name/2","doc":"iex> elements = [{\"w:p\", [], [{\"w:r\", [], [\"some text\"]}]}, {\"w:tbl\", [], []}]\n    iex> SimpleForm.Element.find_many_by_name(elements, [\"w:p\"])\n    [{\"w:p\", [], [{\"w:r\", [], [\"some text\"]}]}]\n    iex> SimpleForm.Element.find_many_by_name(elements, [\"w:r\"])\n    [nil]\n    iex> SimpleForm.Element.find_many_by_name(elements, [\"w:tbl\", \"w:p\"])\n    [{\"w:tbl\", [], []}, {\"w:p\", [], [{\"w:r\", [], [\"some text\"]}]}]\n    iex> SimpleForm.Element.find_many_by_name(elements, [\"w:tbl\", \"w:r\"])\n    [{\"w:tbl\", [], []}, nil]\n    iex> SimpleForm.Element.find_many_by_name(elements, [\"w:sdt\", \"w:p\"])\n    [nil, {\"w:p\", [], [{\"w:r\", [], [\"some text\"]}]}]","ref":"SimpleForm.Element.html#find_many_by_name/2-examples"},{"type":"function","title":"SimpleForm.Element.find_recursive/2","doc":"Recursively find the first element to match the given predicate, or return the given default value.\n\nThis function performs a depth-first search through the children of an element or list of elements,\nand returns the first element for which the predicate returns true.","ref":"SimpleForm.Element.html#find_recursive/2"},{"type":"function","title":"Examples - SimpleForm.Element.find_recursive/2","doc":"iex> SimpleForm.Element.find_recursive(\n    ...>   [{\"w:p\", [], []}, {\"w:r\", [], [\"some text\"]}],\n    ...>   fn element -> element |> SimpleForm.Element.name() === \"w:r\" end\n    ...> )\n    {\"w:r\", [], [\"some text\"]}\n    iex> SimpleForm.Element.find_recursive(\n    ...>   [{\"w:p\", [], [{\"w:r\", [{\"id\", \"1\"}], [\"text\"]}]}, {\"w:r\", [{\"id\", \"2\"}], [\"text\"]}],\n    ...>   fn element -> element |> SimpleForm.Element.name() === \"w:r\" end\n    ...> )\n    {\"w:r\", [{\"id\", \"1\"}], [\"text\"]}\n    iex> SimpleForm.Element.find_recursive([], fn _ -> true end)\n    nil\n    iex> SimpleForm.Element.find_recursive([], fn _ -> true end, \"test\")\n    \"test\"\n    iex> SimpleForm.Element.find_recursive([{\"w:p\", [], [\"text\"]}], fn _ -> false end)\n    nil\n    iex> SimpleForm.Element.find_recursive([{\"w:p\", [], [\"text\"]}], fn _ -> false end, \"default\")\n    \"default\"","ref":"SimpleForm.Element.html#find_recursive/2-examples"},{"type":"function","title":"SimpleForm.Element.find_recursive/3","doc":"","ref":"SimpleForm.Element.html#find_recursive/3"},{"type":"function","title":"SimpleForm.Element.name/1","doc":"Get the name of an element.","ref":"SimpleForm.Element.html#name/1"},{"type":"function","title":"Examples - SimpleForm.Element.name/1","doc":"iex> SimpleForm.Element.name({\"w:p\", [], []})\n    \"w:p\"\n    iex> SimpleForm.Element.name(nil)\n    nil","ref":"SimpleForm.Element.html#name/1-examples"},{"type":"function","title":"SimpleForm.Element.text/1","doc":"Recursively get the text content of an element or list of elements.","ref":"SimpleForm.Element.html#text/1"},{"type":"function","title":"Examples - SimpleForm.Element.text/1","doc":"iex> SimpleForm.Element.text(nil)\n    nil\n    iex> SimpleForm.Element.text(\"some text\")\n    \"some text\"\n    iex> SimpleForm.Element.text({\"w:p\", [], []})\n    \"\"\n    iex> SimpleForm.Element.text([{\"w:p\", [], []}, {\"w:tbl\", [], []}])\n    \"\"\n    iex> SimpleForm.Element.text({\"w:p\", [], [\"some text\"]})\n    \"some text\"\n    iex> SimpleForm.Element.text([{\"w:p\", [], [\"some text\", \" other text.\"]}, {\"w:tbl\", [], [\"more text\"]}, {\"w:tbl\", [], []}])\n    \"some text other text.more text\"\n    iex> SimpleForm.Element.text([{\"w:p\", [], [\"some text\", \" other text.\", \" \"]}, {\"w:tbl\", [], [\"more text\"]}, {\"w:tbl\", [], []}])\n    \"some text other text. more text\"","ref":"SimpleForm.Element.html#text/1-examples"},{"type":"extras","title":"SimpleForm","doc":"# SimpleForm\n\nSimpleForm provides helper functions for working with parsed HTML and XML content, particularly when using [Floki](https://hexdocs.pm/floki/) (an HTML parser) and [Saxy](https://hexdocs.pm/saxy/) (an XML parser) in Elixir projects. It simplifies data extraction, transformation, and manipulation by structuring parsed data in a consistent, tuple-based format, making traversal and modification more intuitive.","ref":"readme.html"},{"type":"extras","title":"Features - SimpleForm","doc":"- Utility functions for extracting and transforming parsed HTML/XML data\n- Seamless integration with Floki's tuple-based structure and Saxy's simple form representation\n- Simplified traversal of document trees and structured form data extraction\n- Reduces boilerplate code when processing structured HTML/XML content","ref":"readme.html#features"},{"type":"extras","title":"Installation - SimpleForm","doc":"Add `simple_form` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:simple_form, \"~> 1.0.0\"}\n  ]\nend\n```\n\nThen, fetch dependencies:\n\n```sh\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Documentation - SimpleForm","doc":"Detailed documentation is available at [HexDocs](https://hexdocs.pm/simple_form).","ref":"readme.html#documentation"},{"type":"extras","title":"License - SimpleForm","doc":"This project is licensed under the [EUPL-1.2 License](LICENSE).","ref":"readme.html#license"},{"type":"extras","title":"1.0.0 (2025-02-05)","doc":"# 1.0.0 (2025-02-05)","ref":"changelog.html"},{"type":"extras","title":"Features - 1.0.0 (2025-02-05)","doc":"* **NLD-625:** initial commit ([7e83588](https://gitlab.com/toegang-voor-iedereen/backend/lib/simple_form/commit/7e83588bded1592cff150200fdc9d0a35fcb39cd))","ref":"changelog.html#features"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}